@@ -1,13 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: app_policy_default_info
-short_description: Information module for App Policy Default Info
+short_description: Information module for App Policy
+  Default
 description:
-  - This module represents an alias of the module app_policy_default_v1_info
+  - Get all App Policy Default.
+  - Get default application policy.
 version_added: '4.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -17,19 +21,24 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Application Policy GetApplicationPolicyDefaultV1
-    description: Complete reference of the GetApplicationPolicyDefaultV1 API.
+  - name: Cisco DNA Center documentation for Application
+      Policy GetApplicationPolicyDefault
+    description: Complete reference of the GetApplicationPolicyDefault
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-application-policy-default
 notes:
-  - SDK Method used are application_policy.ApplicationPolicy.get_application_policy_default_v1,
-  - Paths used are get /dna/intent/api/v1/app-policy-default,
-  - It should be noted that this module is an alias of app_policy_default_v1_info
+  - SDK Method used are
+    application_policy.ApplicationPolicy.get_application_policy_default,
+  - Paths used are
+    get /dna/intent/api/v1/app-policy-default,
 """
+
 EXAMPLES = r"""
-- name: Get all App Policy Default Info
+---
+- name: Get all App Policy Default
   cisco.dnac.app_policy_default_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
