@@ -1,13 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: service_provider_create
-short_description: Resource module for Service Provider Create
+short_description: Resource module for Service Provider
+  Create
 description:
-  - This module represents an alias of the module service_provider_create_v1
+  - Manage operation create of the resource Service
+    Provider Create.
+  - API to create Service Provider Profile QOS .
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -32,18 +37,23 @@ options:
         type: list
     type: dict
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Network Settings CreateSPProfileV1
-    description: Complete reference of the CreateSPProfileV1 API.
+  - name: Cisco DNA Center documentation for Network
+      Settings CreateSPProfile
+    description: Complete reference of the CreateSPProfile
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!create-sp-profile
 notes:
-  - SDK Method used are network_settings.NetworkSettings.create_sp_profile_v1,
-  - Paths used are post /dna/intent/api/v1/service-provider,
-  - It should be noted that this module is an alias of service_provider_create_v1
+  - SDK Method used are
+    network_settings.NetworkSettings.create_sp_profile,
+  - Paths used are
+    post /dna/intent/api/v1/service-provider,
 """
+
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.service_provider_create:
     dnac_host: "{{dnac_host}}"
