@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 # Copyright: (c) 2024, Dell Technologies
-# Apache License version 2.0 (see MODULE-LICENSE or http://www.apache.org/licenses/LICENSE-2.0.txt)
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 """ Ansible module for managing replication pairs on Dell Technologies (Dell) PowerFlex"""
 
@@ -373,35 +373,30 @@ rcg_replication_pairs:
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.dellemc.powerflex.plugins.module_utils.storage.dell \
     import utils
+from ansible_collections.dellemc.powerflex.plugins.module_utils.storage.dell.libraries.powerflex_base \
+    import powerflex_compatibility
+from ansible_collections.dellemc.powerflex.plugins.module_utils.storage.dell.libraries.powerflex_base \
+    import PowerFlexBase
 
 LOG = utils.get_logger('replication_pair')
 
 
-class PowerFlexReplicationPair(object):
+@powerflex_compatibility(min_ver='3.6', max_ver='5.0')
+class PowerFlexReplicationPair(PowerFlexBase):
     """Class with replication pair operations"""
 
     def __init__(self):
         """ Define all parameters required by this module"""
-        self.module_params = utils.get_powerflex_gateway_host_parameters()
-        self.module_params.update(get_powerflex_replication_pair_parameters())
-
+        argument_spec = get_powerflex_replication_pair_parameters()
         mut_ex_args = [['rcg_name', 'rcg_id'], ['pair_id', 'pair_name']]
 
-        # initialize the Ansible module
-        self.module = AnsibleModule(
-            argument_spec=self.module_params,
-            supports_check_mode=True,
-            mutually_exclusive=mut_ex_args)
-
-        utils.ensure_required_libs(self.module)
-
-        try:
-            self.powerflex_conn = utils.get_powerflex_gateway_host_connection(
-                self.module.params)
-            LOG.info("Got the PowerFlex system connection object instance")
-        except Exception as e:
-            LOG.error(str(e))
-            self.module.fail_json(msg=str(e))
+        ansible_module_params = {
+            'argument_spec': argument_spec,
+            'supports_check_mode': True,
+            'mutually_exclusive': mut_ex_args
+        }
+        super().__init__(AnsibleModule, ansible_module_params)
+        super().check_module_compatibility()
 
     def get_replication_pair(self, pair_name=None, pair_id=None):
         """Get replication pair details
