@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -95,22 +98,25 @@ options:
         required: false
         type: dict
         suboptions:
-            add-smil:
+            add_smil:
+                aliases: ['add-smil']
                 type: str
-                description: Deprecated, please rename it to add_smil. Add message encapsulation
+                description: Add message encapsulation
                 choices:
                     - 'disable'
                     - 'enable'
-            addr-type:
+            addr_type:
+                aliases: ['addr-type']
                 type: str
-                description: Deprecated, please rename it to addr_type. From address type
+                description: From address type
                 choices:
                     - 'rfc2822-addr'
                     - 'number'
                     - 'short-code'
-            allow-content-adaptation:
+            allow_content_adaptation:
+                aliases: ['allow-content-adaptation']
                 type: str
-                description: Deprecated, please rename it to allow_content_adaptation. Allow content adaptations
+                description: Allow content adaptations
                 choices:
                     - 'disable'
                     - 'enable'
@@ -140,9 +146,10 @@ options:
             from:
                 type: str
                 description: From address
-            from-sender:
+            from_sender:
+                aliases: ['from-sender']
                 type: str
-                description: Deprecated, please rename it to from_sender. Notification message sent from recipient
+                description: Notification message sent from recipient
                 choices:
                     - 'disable'
                     - 'enable'
@@ -159,9 +166,10 @@ options:
             fmgr_message:
                 type: str
                 description: Message text
-            msg-type:
+            msg_type:
+                aliases: ['msg-type']
                 type: str
-                description: Deprecated, please rename it to msg_type. Message type.
+                description: Message type.
                 required: true
             priority:
                 type: str
@@ -171,9 +179,10 @@ options:
                     - 'normal'
                     - 'high'
                     - 'not-included'
-            rsp-status:
+            rsp_status:
+                aliases: ['rsp-status']
                 type: str
-                description: Deprecated, please rename it to rsp_status. Response status
+                description: Response status
                 choices:
                     - 'success'
                     - 'partial-success'
@@ -201,9 +210,10 @@ options:
                     - 'service-unavail'
                     - 'service-denied'
                     - 'app-denied'
-            smil-part:
+            smil_part:
+                aliases: ['smil-part']
                 type: str
-                description: Deprecated, please rename it to smil_part. Message encapsulation text
+                description: Message encapsulation text
             subject:
                 type: str
                 description: Subject text string
@@ -213,6 +223,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -221,30 +232,30 @@ EXAMPLES = '''
     - name: Replacement message table entries.
       fortinet.fortimanager.fmgr_system_replacemsggroup_mm7:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         replacemsg_group: <your own value>
         state: present # <value in [present, absent]>
         system_replacemsggroup_mm7:
-          add_smil: <value in [disable, enable]>
-          addr_type: <value in [rfc2822-addr, number, short-code]>
-          allow_content_adaptation: <value in [disable, enable]>
-          charset: <value in [us-ascii, utf-8]>
-          class: <value in [personal, advertisement, informational, ...]>
-          format: <value in [none, text, html, ...]>
-          from: <string>
-          from_sender: <value in [disable, enable]>
-          header: <value in [none, http, 8bit]>
-          image: <string>
-          fmgr_message: <string>
-          msg_type: <string>
-          priority: <value in [low, normal, high, ...]>
-          rsp_status: <value in [success, partial-success, client-err, ...]>
-          smil_part: <string>
-          subject: <string>
+          msg_type: "your value" # Required variable, string
+          # add_smil: <value in [disable, enable]>
+          # addr_type: <value in [rfc2822-addr, number, short-code]>
+          # allow_content_adaptation: <value in [disable, enable]>
+          # charset: <value in [us-ascii, utf-8]>
+          # class: <value in [personal, advertisement, informational, ...]>
+          # format: <value in [none, text, html, ...]>
+          # from: <string>
+          # from_sender: <value in [disable, enable]>
+          # header: <value in [none, http, 8bit]>
+          # image: <string>
+          # fmgr_message: <string>
+          # priority: <value in [low, normal, high, ...]>
+          # rsp_status: <value in [success, partial-success, client-err, ...]>
+          # smil_part: <string>
+          # subject: <string>
 '''
 
 RETURN = '''
@@ -288,47 +299,45 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/replacemsg-group/{replacemsg-group}/mm7',
         '/pm/config/global/obj/system/replacemsg-group/{replacemsg-group}/mm7'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/replacemsg-group/{replacemsg-group}/mm7/{mm7}',
-        '/pm/config/global/obj/system/replacemsg-group/{replacemsg-group}/mm7/{mm7}'
-    ]
-
     url_params = ['adom', 'replacemsg-group']
     module_primary_key = 'msg-type'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'replacemsg-group': {'type': 'str', 'api_name': 'replacemsg_group'},
         'replacemsg_group': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_replacemsggroup_mm7': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
-                'add-smil': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'addr-type': {'choices': ['rfc2822-addr', 'number', 'short-code'], 'type': 'str'},
-                'allow-content-adaptation': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'charset': {'choices': ['us-ascii', 'utf-8'], 'type': 'str'},
-                'class': {'choices': ['personal', 'advertisement', 'informational', 'auto', 'not-included'], 'type': 'str'},
-                'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
-                'from': {'type': 'str'},
-                'from-sender': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
-                'image': {'type': 'str'},
-                'fmgr_message': {'type': 'str'},
-                'msg-type': {'required': True, 'type': 'str'},
-                'priority': {'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
+                'add-smil': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'addr-type': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['rfc2822-addr', 'number', 'short-code'], 'type': 'str'},
+                'allow-content-adaptation': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'charset': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['us-ascii', 'utf-8'], 'type': 'str'},
+                'class': {
+                    'v_range': [['6.0.0', '7.6.2']],
+                    'choices': ['personal', 'advertisement', 'informational', 'auto', 'not-included'],
+                    'type': 'str'
+                },
+                'format': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
+                'from': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'from-sender': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'header': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['none', 'http', '8bit'], 'type': 'str'},
+                'image': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'fmgr_message': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'msg-type': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'str'},
+                'priority': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
                 'rsp-status': {
+                    'v_range': [['6.0.0', '7.6.2']],
                     'choices': [
                         'success', 'partial-success', 'client-err', 'oper-restrict', 'addr-err', 'addr-not-found', 'content-refused', 'msg-id-not-found',
                         'link-id-not-found', 'msg-fmt-corrupt', 'app-id-not-found', 'repl-app-id-not-found', 'srv-err', 'not-possible', 'msg-rejected',
@@ -337,10 +346,9 @@ def main():
                     ],
                     'type': 'str'
                 },
-                'smil-part': {'type': 'str'},
-                'subject': {'type': 'str'}
+                'smil-part': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'subject': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'}
             }
-
         }
     }
 
@@ -349,17 +357,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_replacemsggroup_mm7'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
