@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,12 +92,14 @@ options:
         required: false
         type: dict
         suboptions:
-            image-base64:
+            image_base64:
+                aliases: ['image-base64']
                 type: str
-                description: Deprecated, please rename it to image_base64. Image data.
-            image-type:
+                description: Image data.
+            image_type:
+                aliases: ['image-type']
                 type: str
-                description: Deprecated, please rename it to image_type. Image type.
+                description: Image type.
                 choices:
                     - 'gif'
                     - 'jpg'
@@ -109,6 +114,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -121,7 +127,7 @@ EXAMPLES = '''
         adom: ansible
         state: present
         system_replacemsgimage:
-          image-type: jpg # <value in [gif, jpg, tiff, ...]>
+          image_type: jpg # <value in [gif, jpg, tiff, ...]>
           name: ansible-image
 
 - name: Gathering fortimanager facts
@@ -139,7 +145,7 @@ EXAMPLES = '''
           selector: "system_replacemsgimage"
           params:
             adom: "ansible"
-            replacemsg-image: "your_value"
+            replacemsg_image: "your_value"
 '''
 
 RETURN = '''
@@ -183,27 +189,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/replacemsg-image',
         '/pm/config/global/obj/system/replacemsg-image'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/replacemsg-image/{replacemsg-image}',
-        '/pm/config/global/obj/system/replacemsg-image/{replacemsg-image}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_replacemsgimage': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -212,7 +211,6 @@ def main():
                 'image-type': {'choices': ['gif', 'jpg', 'tiff', 'png'], 'type': 'str'},
                 'name': {'required': True, 'type': 'str'}
             }
-
         }
     }
 
@@ -221,17 +219,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_replacemsgimage'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
