@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -101,9 +104,10 @@ options:
                     - 'bypass'
                     - 'monitor'
                     - 'allow'
-            category-id:
+            category_id:
+                aliases: ['category-id']
                 type: int
-                description: Deprecated, please rename it to category_id. Category ID.
+                description: Category ID.
             id:
                 type: int
                 description: ID.
@@ -120,6 +124,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -128,18 +133,18 @@ EXAMPLES = '''
     - name: Configure VideoFilter FortiGuard category.
       fortinet.fortimanager.fmgr_videofilter_profile_fortiguardcategory_filters:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         state: present # <value in [present, absent]>
         videofilter_profile_fortiguardcategory_filters:
-          action: <value in [block, bypass, monitor, ...]>
-          category_id: <integer>
-          id: <integer>
-          log: <value in [disable, enable]>
+          id: 0 # Required variable, integer
+          # action: <value in [block, bypass, monitor, ...]>
+          # category_id: <integer>
+          # log: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -183,28 +188,21 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/videofilter/profile/{profile}/fortiguard-category/filters',
         '/pm/config/global/obj/videofilter/profile/{profile}/fortiguard-category/filters'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/videofilter/profile/{profile}/fortiguard-category/filters/{filters}',
-        '/pm/config/global/obj/videofilter/profile/{profile}/fortiguard-category/filters/{filters}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'videofilter_profile_fortiguardcategory_filters': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
@@ -214,7 +212,6 @@ def main():
                 'id': {'v_range': [['7.0.0', '']], 'required': True, 'type': 'int'},
                 'log': {'v_range': [['7.0.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -223,17 +220,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'videofilter_profile_fortiguardcategory_filters'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
