@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -96,9 +99,10 @@ options:
                     - 'psk'
                     - 'rsa-signature'
                     - 'signature'
-            auto-zone-policy:
+            auto_zone_policy:
+                aliases: ['auto-zone-policy']
                 type: str
-                description: Deprecated, please rename it to auto_zone_policy. Auto-Zone-Policy.
+                description: Auto zone policy.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -116,31 +120,36 @@ options:
                     - 'enable'
                     - 'on-idle'
                     - 'on-demand'
-            dpd-retrycount:
+            dpd_retrycount:
+                aliases: ['dpd-retrycount']
                 type: int
-                description: Deprecated, please rename it to dpd_retrycount. Dpd-Retrycount.
-            dpd-retryinterval:
+                description: Dpd retrycount.
+            dpd_retryinterval:
+                aliases: ['dpd-retryinterval']
                 type: raw
-                description: (list) Deprecated, please rename it to dpd_retryinterval. Dpd-Retryinterval.
-            fcc-enforcement:
+                description: (list) Dpd retryinterval.
+            fcc_enforcement:
+                aliases: ['fcc-enforcement']
                 type: str
-                description: Deprecated, please rename it to fcc_enforcement. Fcc-Enforcement.
+                description: Fcc enforcement.
                 choices:
                     - 'disable'
                     - 'enable'
-            hub2spoke-zone:
+            hub2spoke_zone:
+                aliases: ['hub2spoke-zone']
                 type: raw
-                description: (list or str) Deprecated, please rename it to hub2spoke_zone. Hub2Spoke-Zone.
-            ike-version:
+                description: (list or str) Hub2spoke zone.
+            ike_version:
+                aliases: ['ike-version']
                 type: str
-                description: Deprecated, please rename it to ike_version. Ike-Version.
+                description: Ike version.
                 choices:
                     - '1'
                     - '2'
             ike1dhgroup:
                 type: list
                 elements: str
-                description: Ike1Dhgroup.
+                description: Ike1dhgroup.
                 choices:
                     - '1'
                     - '2'
@@ -161,35 +170,35 @@ options:
                     - '32'
             ike1dpd:
                 type: str
-                description: Ike1Dpd.
+                description: Ike1dpd.
                 choices:
                     - 'disable'
                     - 'enable'
             ike1keylifesec:
                 type: int
-                description: Ike1Keylifesec.
+                description: Ike1keylifesec.
             ike1localid:
                 type: str
-                description: Ike1Localid.
+                description: Ike1localid.
             ike1mode:
                 type: str
-                description: Ike1Mode.
+                description: Ike1mode.
                 choices:
                     - 'main'
                     - 'aggressive'
             ike1natkeepalive:
                 type: int
-                description: Ike1Natkeepalive.
+                description: Ike1natkeepalive.
             ike1nattraversal:
                 type: str
-                description: Ike1Nattraversal.
+                description: Ike1nattraversal.
                 choices:
                     - 'disable'
                     - 'enable'
                     - 'forced'
             ike1proposal:
                 type: str
-                description: Ike1Proposal.
+                description: Ike1proposal.
                 choices:
                     - 'des-md5'
                     - 'des-sha1'
@@ -250,14 +259,14 @@ options:
                     - 'chacha20poly1305-prfsha512'
             ike2autonego:
                 type: str
-                description: Ike2Autonego.
+                description: Ike2autonego.
                 choices:
                     - 'disable'
                     - 'enable'
             ike2dhgroup:
                 type: list
                 elements: str
-                description: Ike2Dhgroup.
+                description: Ike2dhgroup.
                 choices:
                     - '1'
                     - '2'
@@ -278,26 +287,26 @@ options:
                     - '32'
             ike2keepalive:
                 type: str
-                description: Ike2Keepalive.
+                description: Ike2keepalive.
                 choices:
                     - 'disable'
                     - 'enable'
             ike2keylifekbs:
                 type: int
-                description: Ike2Keylifekbs.
+                description: Ike2keylifekbs.
             ike2keylifesec:
                 type: int
-                description: Ike2Keylifesec.
+                description: Ike2keylifesec.
             ike2keylifetype:
                 type: str
-                description: Ike2Keylifetype.
+                description: Ike2keylifetype.
                 choices:
                     - 'seconds'
                     - 'kbs'
                     - 'both'
             ike2proposal:
                 type: str
-                description: Ike2Proposal.
+                description: Ike2proposal.
                 choices:
                     - 'null-md5'
                     - 'null-sha1'
@@ -361,21 +370,24 @@ options:
                     - 'aes128gcm'
                     - 'aes256gcm'
                     - 'chacha20poly1305'
-            inter-vdom:
+            inter_vdom:
+                aliases: ['inter-vdom']
                 type: str
-                description: Deprecated, please rename it to inter_vdom. Inter-Vdom.
+                description: Inter vdom.
                 choices:
                     - 'disable'
                     - 'enable'
-            intf-mode:
+            intf_mode:
+                aliases: ['intf-mode']
                 type: str
-                description: Deprecated, please rename it to intf_mode. Intf-Mode.
+                description: Intf mode.
                 choices:
                     - 'off'
                     - 'on'
-            localid-type:
+            localid_type:
+                aliases: ['localid-type']
                 type: str
-                description: Deprecated, please rename it to localid_type. Localid-Type.
+                description: Localid type.
                 choices:
                     - 'auto'
                     - 'fqdn'
@@ -387,12 +399,14 @@ options:
                 type: str
                 description: Name.
                 required: true
-            negotiate-timeout:
+            negotiate_timeout:
+                aliases: ['negotiate-timeout']
                 type: int
-                description: Deprecated, please rename it to negotiate_timeout. Negotiate-Timeout.
-            npu-offload:
+                description: Negotiate timeout.
+            npu_offload:
+                aliases: ['npu-offload']
                 type: str
-                description: Deprecated, please rename it to npu_offload. Npu-Offload.
+                description: Npu offload.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -402,9 +416,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            psk-auto-generate:
+            psk_auto_generate:
+                aliases: ['psk-auto-generate']
                 type: str
-                description: Deprecated, please rename it to psk_auto_generate. Psk-Auto-Generate.
+                description: Psk auto generate.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -417,12 +432,14 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            rsa-certificate:
+            rsa_certificate:
+                aliases: ['rsa-certificate']
                 type: str
-                description: Deprecated, please rename it to rsa_certificate. Rsa-Certificate.
-            spoke2hub-zone:
+                description: Rsa certificate.
+            spoke2hub_zone:
+                aliases: ['spoke2hub-zone']
                 type: raw
-                description: (list or str) Deprecated, please rename it to spoke2hub_zone. Spoke2Hub-Zone.
+                description: (list or str) Spoke2hub zone.
             topology:
                 type: str
                 description: Topology.
@@ -430,15 +447,18 @@ options:
                     - 'meshed'
                     - 'star'
                     - 'dialup'
-            vpn-zone:
+            vpn_zone:
+                aliases: ['vpn-zone']
                 type: raw
-                description: (list or str) Deprecated, please rename it to vpn_zone. Vpn-Zone.
-            network-id:
+                description: (list or str) Vpn zone.
+            network_id:
+                aliases: ['network-id']
                 type: int
-                description: Deprecated, please rename it to network_id. Network-Id.
-            network-overlay:
+                description: Network id.
+            network_overlay:
+                aliases: ['network-overlay']
                 type: str
-                description: Deprecated, please rename it to network_overlay. Network-Overlay.
+                description: Network overlay.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -448,6 +468,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -456,88 +477,88 @@ EXAMPLES = '''
     - name: Vpnmgr vpntable
       fortinet.fortimanager.fmgr_vpnmgr_vpntable:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         vpnmgr_vpntable:
-          authmethod: <value in [psk, rsa-signature, signature]>
-          auto_zone_policy: <value in [disable, enable]>
-          certificate: <list or string>
-          description: <string>
-          dpd: <value in [disable, enable, on-idle, ...]>
-          dpd_retrycount: <integer>
-          dpd_retryinterval: <list or integer>
-          fcc_enforcement: <value in [disable, enable]>
-          hub2spoke_zone: <list or string>
-          ike_version: <value in [1, 2]>
-          ike1dhgroup:
-            - 1
-            - 2
-            - 5
-            - 14
-            - 15
-            - 16
-            - 17
-            - 18
-            - 19
-            - 20
-            - 21
-            - 27
-            - 28
-            - 29
-            - 30
-            - 31
-            - 32
-          ike1dpd: <value in [disable, enable]>
-          ike1keylifesec: <integer>
-          ike1localid: <string>
-          ike1mode: <value in [main, aggressive]>
-          ike1natkeepalive: <integer>
-          ike1nattraversal: <value in [disable, enable, forced]>
-          ike1proposal: <value in [des-md5, des-sha1, 3des-md5, ...]>
-          ike2autonego: <value in [disable, enable]>
-          ike2dhgroup:
-            - 1
-            - 2
-            - 5
-            - 14
-            - 15
-            - 16
-            - 17
-            - 18
-            - 19
-            - 20
-            - 21
-            - 27
-            - 28
-            - 29
-            - 30
-            - 31
-            - 32
-          ike2keepalive: <value in [disable, enable]>
-          ike2keylifekbs: <integer>
-          ike2keylifesec: <integer>
-          ike2keylifetype: <value in [seconds, kbs, both]>
-          ike2proposal: <value in [null-md5, null-sha1, des-null, ...]>
-          inter_vdom: <value in [disable, enable]>
-          intf_mode: <value in [off, on]>
-          localid_type: <value in [auto, fqdn, user-fqdn, ...]>
-          name: <string>
-          negotiate_timeout: <integer>
-          npu_offload: <value in [disable, enable]>
-          pfs: <value in [disable, enable]>
-          psk_auto_generate: <value in [disable, enable]>
-          psksecret: <list or string>
-          replay: <value in [disable, enable]>
-          rsa_certificate: <string>
-          spoke2hub_zone: <list or string>
-          topology: <value in [meshed, star, dialup]>
-          vpn_zone: <list or string>
-          network_id: <integer>
-          network_overlay: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # authmethod: <value in [psk, rsa-signature, signature]>
+          # auto_zone_policy: <value in [disable, enable]>
+          # certificate: <list or string>
+          # description: <string>
+          # dpd: <value in [disable, enable, on-idle, ...]>
+          # dpd_retrycount: <integer>
+          # dpd_retryinterval: <list or integer>
+          # fcc_enforcement: <value in [disable, enable]>
+          # hub2spoke_zone: <list or string>
+          # ike_version: <value in [1, 2]>
+          # ike1dhgroup:
+          #   - "1"
+          #   - "2"
+          #   - "5"
+          #   - "14"
+          #   - "15"
+          #   - "16"
+          #   - "17"
+          #   - "18"
+          #   - "19"
+          #   - "20"
+          #   - "21"
+          #   - "27"
+          #   - "28"
+          #   - "29"
+          #   - "30"
+          #   - "31"
+          #   - "32"
+          # ike1dpd: <value in [disable, enable]>
+          # ike1keylifesec: <integer>
+          # ike1localid: <string>
+          # ike1mode: <value in [main, aggressive]>
+          # ike1natkeepalive: <integer>
+          # ike1nattraversal: <value in [disable, enable, forced]>
+          # ike1proposal: <value in [des-md5, des-sha1, 3des-md5, ...]>
+          # ike2autonego: <value in [disable, enable]>
+          # ike2dhgroup:
+          #   - "1"
+          #   - "2"
+          #   - "5"
+          #   - "14"
+          #   - "15"
+          #   - "16"
+          #   - "17"
+          #   - "18"
+          #   - "19"
+          #   - "20"
+          #   - "21"
+          #   - "27"
+          #   - "28"
+          #   - "29"
+          #   - "30"
+          #   - "31"
+          #   - "32"
+          # ike2keepalive: <value in [disable, enable]>
+          # ike2keylifekbs: <integer>
+          # ike2keylifesec: <integer>
+          # ike2keylifetype: <value in [seconds, kbs, both]>
+          # ike2proposal: <value in [null-md5, null-sha1, des-null, ...]>
+          # inter_vdom: <value in [disable, enable]>
+          # intf_mode: <value in [off, on]>
+          # localid_type: <value in [auto, fqdn, user-fqdn, ...]>
+          # negotiate_timeout: <integer>
+          # npu_offload: <value in [disable, enable]>
+          # pfs: <value in [disable, enable]>
+          # psk_auto_generate: <value in [disable, enable]>
+          # psksecret: <list or string>
+          # replay: <value in [disable, enable]>
+          # rsa_certificate: <string>
+          # spoke2hub_zone: <list or string>
+          # topology: <value in [meshed, star, dialup]>
+          # vpn_zone: <list or string>
+          # network_id: <integer>
+          # network_overlay: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -581,27 +602,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/vpnmgr/vpntable',
         '/pm/config/global/obj/vpnmgr/vpntable'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/vpnmgr/vpntable/{vpntable}',
-        '/pm/config/global/obj/vpnmgr/vpntable/{vpntable}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'vpnmgr_vpntable': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -623,7 +637,7 @@ def main():
                 },
                 'ike1dpd': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'ike1keylifesec': {'no_log': True, 'type': 'int'},
-                'ike1localid': {'type': 'str'},
+                'ike1localid': {'v_range': [['6.0.0', '7.4.6'], ['7.6.0', '']], 'type': 'str'},
                 'ike1mode': {'choices': ['main', 'aggressive'], 'type': 'str'},
                 'ike1natkeepalive': {'type': 'int'},
                 'ike1nattraversal': {'choices': ['disable', 'enable', 'forced'], 'type': 'str'},
@@ -681,7 +695,6 @@ def main():
                 'network-id': {'v_range': [['6.2.5', '']], 'type': 'int'},
                 'network-overlay': {'v_range': [['6.2.5', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -690,17 +703,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpnmgr_vpntable'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
