@@ -75,7 +75,7 @@ options:
     type: str
   filtervalue:
     description:
-    - Specifies (key=value) combination that helps in returning a subset of objects satisfying the condition.
+    - Specifies a set of one or more (key=value) combination separated by a colon that helps in returning a subset of objects satisfying the condition.
     type: str
   gather_subset:
     type: list
@@ -95,6 +95,7 @@ options:
     - hc - lists information for host clusters.
     - fc - lists information for FC connectivity.
     - fcport - lists information for FC ports.
+    - fabricport -  list the FDMI information that is discovered by the system.
     - targetportfc - lists information for WWPN which is required to set up
                      FC zoning and to display the current failover status
                      of host I/O ports.
@@ -160,8 +161,12 @@ options:
     - availablepatch - display the patches that are compatible with the SVC version.
     - patch - displays a list of all the patches on a specific node.
     - systempatches - displays patches installed on all the nodes in the system.
+    - grid - displays the summarized view of flashsystem grid.
+    - gridmembers - displays the summarized view of flashsystem grid members.
+    - gridsystem - displays the information about all systems in the flashsystem grid.
+    - gridpartition - displays the information about all partitions in the flashsystem grid.
     choices: [vol, pool, node, iog, host, hostvdiskmap, vdiskhostmap, hc, fcport
-              , iscsiport, fc, fcmap, fcconsistgrp, rcrelationship, rcconsistgrp
+              , fabricport, iscsiport, fc, fcmap, fcconsistgrp, rcrelationship, rcconsistgrp
               , vdiskcopy, targetportfc, array, system, 'cloudaccount', 'cloudaccountusage',
                'ldapserver', 'drive', 'user', 'usergroup', 'ownershipgroup',
                'partnership', 'replicationpolicy', 'cloudbackup', 'enclosurestats',
@@ -172,7 +177,7 @@ options:
                'truststore', 'callhome', 'ip', 'portset', 'safeguardedpolicy',
                'mdisk', 'safeguardedpolicyschedule', 'cloudimportcandidate', 'eventlog', 'driveclass', 'security', 'partition',
                'volumegroupreplication', 'plugin', 'quorum', 'enclosure', 'snmpserver', 'testldapserver', 'availablepatch',
-               'patch', 'systempatches', all]
+               'patch', 'systempatches', 'grid', 'gridmembers', 'gridsystem', 'gridpartition', all]
   command_list:
     type: list
     elements: str
@@ -189,74 +194,92 @@ notes:
 EXAMPLES = '''
 - name: Get volume info
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     gather_subset: vol
 - name: Get volume info
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     objectname: volumename
     gather_subset: vol
 - name: Get pool info
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     gather_subset: pool
 - name: Get population information about volumes and volumegroups of type clone or thinclone
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
-    gather_subset: ['volumepopulation','volumegrouppopulation']
+    gather_subset: ['volumepopulation', 'volumegrouppopulation']
 - name: Get all info related to volume 'Volume1'
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     gather_subset: vol
     objectname: Volume1
 - name: Get detailed info of all volumes.
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     gather_subset: vol
     objectname: all
 - name: Get detailed info for objects returned by lsvdiskcopy using command_list.
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     command_list: lsvdiskcopy
     objectname: all
 - name: Get detailed info of multiple objects using gather_subset and command_list.
   ibm.storage_virtualize.ibm_svc_info:
-    clustername: "{{clustername}}"
-    domain: "{{domain}}"
-    username: "{{username}}"
-    password: "{{password}}"
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
     log_path: /tmp/ansible.log
     gather_subset: [vol, host]
     command_list: [lsvdiskcopy, lssite]
     objectname: all
+- name: Get list of candidate drives info using filtervalue and gather_subset.
+  ibm.storage_virtualize.ibm_svc_info:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/ansible.log
+    gather_subset: drive
+    filtervalue: "use=candidate:status=online"
+- name: Get list of replication type portsets info using filtervalue and command_list.
+  ibm.storage_virtualize.ibm_svc_info:
+    clustername: "{{ clustername }}"
+    domain: "{{ domain }}"
+    username: "{{ username }}"
+    password: "{{ password }}"
+    log_path: /tmp/ansible.log
+    command_list: lsportset
+    filtervalue: "type=replication"
 '''
 
 RETURN = '''
@@ -349,7 +372,7 @@ EmailUser:
     type: list
     elements: dict
     sample: [{...}]
-FCConnectivitie:
+FCConnectivity:
     description:
         - Data will be populated when I(gather_subset=fc) or I(gather_subset=all)
         - Lists information for FC connectivity
@@ -381,6 +404,14 @@ FCPort:
     type: list
     elements: dict
     sample: [{...}]
+FabricPort:
+    description:
+        - Data will be populated when I(gather_subset=fabricport) or I(gather_subset=all)
+        - List the FDMI information that is discovered by the system.
+    returned: success
+    type: list
+    elements: dict
+    sample: [{...}]
 Host:
     description:
         - Data will be populated when I(gather_subset=host) or I(gather_subset=all)
@@ -806,7 +837,34 @@ Systempatches:
     returned: success
     type: list
     elements: dict
-    sample: [{...}]
+FlashsystemGrid:
+    description:
+        - Data will be populated when I(gather_subset=grid) or I(gather_subset=all)
+        - Displays summarized view of flashsystem grid.
+    returned: success
+    type: list
+    elements: dict
+FlashsystemGridMembers:
+    description:
+        - Data will be populated when I(gather_subset=gridmembers) or I(gather_subset=all)
+        - Displays summarized view of flashsystem grid members.
+    returned: success
+    type: list
+    elements: dict
+FlashsystemGridSystem:
+    description:
+        - Data will be populated when I(gather_subset=gridsystem) or I(gather_subset=all)
+        - Displays the information about all systems in the flashsystem grid.
+    returned: success
+    type: list
+    elements: dict
+FlashsystemGridPartition:
+    description:
+        - Data will be populated when I(gather_subset=gridpartition) or I(gather_subset=all)
+        - Displays the information about all partitions in the flashsystem grid.
+    returned: success
+    type: list
+    elements: dict
 '''
 
 from traceback import format_exc
@@ -834,6 +892,7 @@ class IBMSVCGatherInfo(object):
                                             'hc',
                                             'fc',
                                             'fcport',
+                                            'fabricport',
                                             'targetportfc',
                                             'iscsiport',
                                             'fcmap',
@@ -892,6 +951,10 @@ class IBMSVCGatherInfo(object):
                                             'availablepatch',
                                             'patch',
                                             'systempatches',
+                                            'grid',
+                                            'gridmembers',
+                                            'gridsystem',
+                                            'gridpartition',
                                             'all'
                                             ]),
                 command_list=dict(type='list', elements='str', required=False)
@@ -1077,6 +1140,7 @@ class IBMSVCGatherInfo(object):
                                                 lsvolumegroupsnapshotschedule etc.)
                                                 '''
                                                 return output
+
                                     output[op_key] = op_key_list
                                 else:
                                     output[op_key] = get_all_objects
@@ -1093,7 +1157,7 @@ class IBMSVCGatherInfo(object):
                                 In few cases id is not mentioned or id is invalid with command lscommand <id>.
                                 (ex. lsauthmultifactorduo, lsauthmultifactorverify, lsauthsinglesignon, lscloudcallhome,
                                 lsencryption, lskeyserverisklm, lsldap, lslicense, lsnodestatus, lsproxy, lssecurity, lssra,
-                                lssystem, lssystemcert, lssystemethernet etc.)
+                                lssystem, lssystemcert, lssystemethernet, lsgrid, lsgridmembers etc.)
                                 '''
                                 return output
                     else:
@@ -1141,11 +1205,12 @@ class IBMSVCGatherInfo(object):
             'HostVdiskMap': [],
             'VdiskHostMap': [],
             'HostCluster': [],
-            'FCConnectivitie': [],
+            'FCConnectivity': [],
             'FCConsistgrp': [],
             'RCConsistgrp': [],
             'VdiskCopy': [],
             'FCPort': [],
+            'FabricPort': [],
             'TargetPortFC': [],
             'iSCSIPort': [],
             'FCMap': [],
@@ -1198,6 +1263,10 @@ class IBMSVCGatherInfo(object):
             'Testldapserver': [],
             'Availablepatch': [],
             'Patch': [],
+            'FlashsystemGrid': [],
+            'FlashsystemGridMembers': [],
+            'FlashsystemGridSystem': [],
+            'FlashsystemGridPartition': [],
             'Systempatches': []
         }
 
@@ -1210,8 +1279,9 @@ class IBMSVCGatherInfo(object):
             'hostvdiskmap': ('HostVdiskMap', 'lshostvdiskmap', False, None),
             'vdiskhostmap': ('VdiskHostMap', 'lsvdiskhostmap', True, None),
             'hc': ('HostCluster', 'lshostcluster', False, '7.7.1.0'),
-            'fc': ('FCConnectivitie', 'lsfabric', False, None),
+            'fc': ('FCConnectivity', 'lsfabric', False, None),
             'fcport': ('FCPort', 'lsportfc', False, None),
+            'fabricport': ('FabricPort', 'lsfabricport', False, '8.6.0.0'),
             'iscsiport': ('iSCSIPort', 'lsportip', False, None),
             'fcmap': ('FCMap', 'lsfcmap', False, None),
             'rcrelationship': ('RemoteCopy', 'lsrcrelationship', False, None),
@@ -1269,7 +1339,11 @@ class IBMSVCGatherInfo(object):
             'testldapserver': ('Testldapserver', 'testldapserver', False, '6.3.0.0'),
             'availablepatch': ('Availablepatch', 'lsavailablepatch', False, '8.7.0.0'),
             'patch': ('Patch', 'lspatch', False, '8.5.4.0'),
-            'systempatches': ('Systempatches', 'lssystempatches', False, '8.5.4.0')
+            'systempatches': ('Systempatches', 'lssystempatches', False, '8.5.4.0'),
+            'grid': ('FlashsystemGrid', 'lsgrid', False, '8.7.1.0'),
+            'gridmembers': ('FlashsystemGridMembers', 'lsgridmembers', False, '8.7.2.0'),
+            'gridsystem': ('FlashsystemGridSystem', 'lsgridsystem', False, '8.7.3.0'),
+            'gridpartition': ('FlashsystemGridPartition', 'lsgridpartition', False, '8.7.2.0')
         }
         if command_list:
             for cmd in command_list:
